ConflictType

Enum ConflictType 

pub enum ConflictType {
    Data,
    NotFound,
    Conflict,
    Constraint,
    ForeignKey,
}
The category of conflict encountered while applying a changeset.

Variants



Data

The row exists but its current values differ from the expected old values.



NotFound

The row to update or delete does not exist in the target database.



Conflict

A unique-constraint violation occurred (e.g. duplicate key on INSERT).



Constraint

A non-unique constraint violation occurred (CHECK, NOT NULL, etc.).



ForeignKey

A foreign-key constraint violation occurred.